<?php
/**
 * Add ARIA and svg icons to links
 *
 * The following type of links filtered:
 * 	PDF, external links, image in links. 
 *
 * Theme: Manduca - focus on accessibility
 * @ Since 17.9.6
 * */


 Class Link_Functions {
   
   // Variable to debug this class. emtpy means no debug. 
   protected $debug = false;
   
   function add_hook_to_wp() {
		 $this->register_hooks();
   }
		
   private function register_hooks() {
		//Add content more link
		add_filter( 'the_content_more_link', array( $this, 'more_link_create_html' ) );
		add_filter( 'excerpt_more', array( $this, 'more_link_create_html' ) );
				
		// Add read-more link to manual excerpt
		add_filter('get_the_excerpt', array( $this , 'manual_excerpt' ) );
		
		// filters have high (late) priority to make sure that any markup plugins have done their HTML. 
		add_filter( 'the_content', array( $this , 'filter_links' ) , 999 );
		add_filter( 'the_excerpt', array( $this , 'filter_links' ) , 999 );
		add_filter( 'comment_text', array( $this , 'filter_links' ) , 999 );
		add_filter( 'widget_text', array( $this , 'filter_links' ) , 999 );
		
	}
	
	/*
	 * Filters the <a> elements and add accessibility elements
	 *
	 * @param $text : string text to filter
	 * 	match information:
	 * 		0: full link
	 * 		1: attributes befor href
	 * 		2: protocol
	 * 		3: link uri
	 * 		4: attributes after href
	 * 		5: link title
	 **/
	function filter_links( $text ) {
		$pattern = '/<a (.*?)href="(.*?)\/?\/(.*?)"(.*?)>(.*?)<\/a>/i';
		$text = preg_replace_callback( $pattern, array( $this, 'parse_links' ) , $text );
		return $text;
	}

	
	
	/**
	 * Callback function of preg_replace to parse links
	 *
	 * @param $matches HTML code to filter
	 *
	 * @return modified HTML code, where class="ext-links" are added. 
	 **/
	function parse_links( $matches ) {

		if ( ! isset( $matches[2][0] )  ) {
			$anchorLink = true;
			
		}
		elseif( $matches[2][0] !=='#') {
			$anchorLink = false;
		}
		else {
			$anchorLink = false;
		}
		
				  debug::show_variable( $this->debug, __METHOD__ .':  match arrgs of link' , $matches );
		
		$linkDomain = $this->get_domain_name_from_uri( $matches[3] );
		$homeDomain = $this->get_domain_name_from_uri( $_SERVER["HTTP_HOST"] );
		
		// If the link has img in it, add class="image-link".
		if( strpos( $matches[5], 'img' ) !== false ) {
				
				$matches = $this->append_class_to_html( $matches , 'image-link' );
				$matches [4] .= ' aria-label="' .__( 'include image', 'manduca' ) .'" ';
				$pattern = $this->construct_anchor( $matches, '' );
			
		}
		
		// If it is an external link	
		elseif(  $linkDomain !=  $homeDomain &&  $anchorLink === false ) {
			
			$matches = $this->append_class_to_html( $matches , 'ext-link' );
			$matches [4] .= 'aria-label="' .__( 'external', 'manduca' ) .'" ';
			
			$pattern = $this->construct_anchor( $matches, manduca_get_svg( array( 'icon' => 'extlink') ) );
			
		
		}
		
		//It is not an external link
		else {
			
			// If Word document
				
			if( strpos( $matches[3], 'docx' ) !== false || strpos( $matches[3], 'doc' ) !== false  ) {
				
				$matches = $this->append_class_to_html( $matches , 'media' );
				$matches [4] .= 'aria-label="' .__( 'MS Word document', 'manduca' ) .'" ';
				$pattern = $this->construct_anchor( $matches, manduca_get_svg( array( 'icon' => 'word') ) );
			
			}
			elseif( strpos( $matches[3], 'xlsx' ) !== false || strpos( $matches[3], 'xls' ) !== false  ) {
			
				$matches = $this->append_class_to_html( $matches , 'media' );
				$matches [4] .= 'aria-label="' .__( 'MS Excel document', 'manduca' ) .'" ';
				$pattern = $this->construct_anchor ( $matches, manduca_get_svg( array( 'icon' => 'excel') ) );
			
			}
			elseif( strpos( $matches[3], 'pdf' ) !== false ) {
			
				$matches = $this->append_class_to_html( $matches , 'media' );
				$matches [4] .= 'aria-label="' .__( 'PDF document', 'manduca' ) .'" ';
				$pattern = $this->construct_anchor ( $matches, manduca_get_svg( array( 'icon' => 'pdf') ) );
			
			}
			else {
			
				$pattern = $this->construct_anchor( $matches, '' );
			
			}
		
		//end of not external link branch	
		}
		
		
		return $pattern;
	}
	
	function more_link_create_html() {
		   $args  				= $this->read_more_button_text();
		 
		   $more_link_create_html 	= sprintf( '<div  class="%2$s"><a href="%1$s"id="continue-reading-%3$s" aria-labelledby="post-%3$s" >%4$s %5$s</a></div>',
									   get_permalink(),
									   $args[ 'classes' ],
									   get_the_ID(),
									   $args[ 'text' ],
									   $args[ 'icon' ]
									  );
		   return $more_link_create_html;
	   }
 
	
	
	function manual_excerpt ( $excerpt ) {
		global $post;
		if( $post->post_excerpt ) {
				return $excerpt .$this->more_link_create_html();
		} else {
				return $excerpt;
		}
	}
	
	/*
	* Get domain name from url 
	*
	* @parameter string $uri URI of to be analized 
	* */
	
	function get_domain_name_from_uri( $uri ) {
		preg_match( '/^(http:\/\/)?([^\/]+)/i', $uri, $matches );
		$host = $matches[2];
		preg_match( '/[^\.\/]+\.[^\.\/]+$/', $host, $matches );
		return $host;
	}

	


	
	
	
	/**
	 * Append HTMl class to the HTMl tokens
	 *
	 * @param array: tokens of link
	 * @param class: class to be appended.
	 *
	 * @ return array: appended with class
	 * @ since 17.9.7
	 **/
	
	 function append_class_to_html( $tokens, $class ) {
		
			// Check the tokens after href
			if( !empty ($tokens[4]) ) {
				if ( strpos( $tokens[4], 'class=') !== FALSE   ) {
					// Already has calss attribute
					$tokens[4] = str_replace ( 'class="', 'class="' .$class .' ', $tokens[4]);
			
				}
			}
			
			// Check the tokens before href
			elseif( !empty ($tokens[1]) ) {
				if ( strpos( $tokens[1], 'class=') !== FALSE   ) {
					// Already has calss attribute
					$tokens[1] = str_replace ( 'class="', 'class="' .$class .' ', $tokens[1]);
				}
			}
			
			//If there is no class attribute. 
			else {
				$tokens[4] .= 'class="' .$class .'" ';
			}
			return $tokens;
	}
 
 
 
	/**
	 * Construct anchor (<a>) link of media links and adds an icon
	 *
	 * @param array $tokens parts of the anchor link
	 * @param array $tokens parts of the anchor link
	 *
	 * @return HTML element
	 *
	 * @since 17.9.7
	 **/
		
	function construct_anchor( $tokens, $svg ) {
		return sprintf ( '<a href="%1$s//%2$s" %3$s %4$s>%5$s%6$s</a>',
								   $tokens[2],
								   $tokens[3],
								   $tokens[1],
								   $tokens[4],
								   $tokens[5],
								   $svg
								   );
	}


	
	
	/**
	 * Customize read more, excerpt more button
	 * This is a new version of breadcrumb
	 *
	 * @param  array of parameters
	 * 				icon : svg icon in icon-sprite used to indicate expand/collapse status. 
	 * 
	 * @since 17.9.17
	 **/
	public function read_more_button_text() {
			//Translators: text of the read more and excerpt more buttons
			$args[ "text" ] 	= __( 'Continue reading', 'manduca' );
			$args[ 'icon' ] 	= manduca_get_svg( array( 'icon' => 'angle-right' ) ) ;
			$args[ 'classes']	= 'more-link'; 
			
			// Filter of args 
			return  $args;
			
	}
 }